Rousset et al. (2016) presented the loaloa data set which describes prevalence of infection by the nematode Loa loa in North Cameroon, 1991- 2001. The study investigated the relationship between altitude, vegetation indices, and prevalence of the parasite.
data("Loaloa")A data frame with 197 observations on the following 11 variables.
longitudelongitude, in degrees
latitudelatitude, in degrees
ntotsample size per location
nposnumber of infected individuals per location
maxNDVImaximum normalised-difference vegetation index (NDVI) from repeated satellite scans
seNDVIstandard error of NDVI
elev1altitude, in m
elev2additional altitude variables derived from the previous one, provided for convenience respectively, positive values of altitude-650,
elev3positive values of altitude-1000
elev4positive values of altitude-1300
maxNDVI1a copy of maxNDVI modified as maxNDVI1 (maxNDVI1=0.8 if maxNDVI>0.8, maxNDVI1=maxNDVI otherwise)
Rousset, F., Ferdy, J.B. and Courtiol, A. (2016). spaMM: Mixed Models, Particularly Spatial GLMMs. R package version 1.7.2.